# Project Authors

This project was initially created by [Leonardo Uieda](http://www.leouieda.com/).

The following people have made contributions to the project (in alphabetical order by
last name) and are considered "The Pooch Developers":

* [John Leeman](https://github.com/jrleeman)
* [Santiago R. Soler](https://github.com/santisoler)
* [Leonardo Uieda](http://www.leouieda.com/)
